In the ld documentation under Builtin Functions:

  BLOCK(exp)

    This is a synonym for ALIGN, for compatibility with older linker scripts.

Clang's linker (lld) doesn't know about BLOCK so remove this use of it.

Link: https://github.com/ClangBuiltLinux/linux/issues/253
Signed-off-by: Joel Stanley <j...@jms.id.au>
---
 arch/powerpc/kernel/vmlinux.lds.S | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/arch/powerpc/kernel/vmlinux.lds.S 
b/arch/powerpc/kernel/vmlinux.lds.S
index ad1c77f71f54..3ae4c959f95b 100644
--- a/arch/powerpc/kernel/vmlinux.lds.S
+++ b/arch/powerpc/kernel/vmlinux.lds.S
@@ -86,11 +86,11 @@ SECTIONS
 
 #ifdef CONFIG_PPC64
        /*
         * BLOCK(0) overrides the default output section alignment because
         * this needs to start right after .head.text in order for fixed
         * section placement to work.
         */
-       .text BLOCK(0) : AT(ADDR(.text) - LOAD_OFFSET) {
+       .text ALIGN(0) : AT(ADDR(.text) - LOAD_OFFSET) {
 #ifdef CONFIG_LD_HEAD_STUB_CATCH
                KEEP(*(.linker_stub_catch));
                . = . ;
@@ -86,11 +86,11 @@ SECTIONS
 #ifdef CONFIG_PPC64
        /*
-        * BLOCK(0) overrides the default output section alignment because
+        * ALIGN(0) overrides the default output section alignment because
         * this needs to start right after .head.text in order for fixed
         * section placement to work.
-- 
2.19.1

Reply via email to